@@ -1,5 +1,6 @@
 import torch
 import torch.nn as nn
+import numpy as np
 
 
 class FocalLoss(nn.Module):
@@ -12,9 +13,10 @@ class FocalLoss(nn.Module):
         self.gamma = gamma
 
     def forward(self, x, target):
+        eps = np.finfo(float).epsilon
         p_t = torch.where(target == 1, x, 1-x)
-        fl = - 1 * (1 - p_t) ** self.gamma * torch.log(p_t)
-        fl = torch.where(target == 1, fl * self.alpha, fl)
+        fl = - 1 * (1 - p_t) ** self.gamma * torch.log(p_t + eps)
+        fl = torch.where(target == 1, fl * self.alpha, fl * (1 - self.alpha))
         return self._reduce(fl)
 
     def _reduce(self, x):
